@@ -71,5 +71,5 @@ class Payment:
         return r.json()
 
     def refund(self,payment_id:str):
-        r = requests.post(self.url + '/payments/{}/refunds'.format(payment_id), headers=self.headers)
+        r = requests.post(self.url + f'/payments/{payment_id}/refunds', headers=self.headers)
         return r.json()
\ No newline at end of file
